ScrollbarDecoration class
Constructors
- ScrollbarDecoration({double minThumbLength = 18.0, bool? thumbVisibility = true, Radius? radius, double? thickness, Color? thumbColor, OutlinedBorder? shape, ScrollbarOrientation orientation = ScrollbarOrientation.right, bool? trackVisibility, Radius? trackRadius, double? crossAxisMargin = 0, Color? trackColor, bool? interactive = true, Color? trackBorderColor, Duration fadeDuration = const Duration(milliseconds: 300), Duration timeToFade = const Duration(milliseconds: 600), Duration pressDuration = const Duration(milliseconds: 100)})
Properties
- crossAxisMargin ↔ double?
-
Distance from the scrollbar thumb's side to the nearest cross axis edge in logical pixels.
getter/setter pair
- fadeDuration ↔ Duration
-
The Duration of the fade animation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactive ↔ bool?
-
Whether the Scrollbar should be interactive and respond to dragging on the thumb, or tapping in the track area.
Defaults to true when null, unless on Android, which will default to false when null.
getter/setter pair
- minThumbLength ↔ double
-
Mustn't be null and the value has to be greater or equal to
minOverscrollLength, which in turn is >= 0. Defaults to 18.0.getter/setter pair - orientation ↔ ScrollbarOrientation
-
Dictates the orientation of the scrollbar.
getter/setter pair
- pressDuration ↔ Duration
-
The Duration of time that a LongPress will trigger the drag gesture of the scrollbar thumb.
Cannot be null, defaults to Duration.zero.
getter/setter pair
- radius ↔ Radius?
-
The Radius of the scrollbar's thumb.
Only one of radius and shape may be specified. For a rounded rectangle,
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape ↔ OutlinedBorder?
-
The OutlinedBorder of the scrollbar's thumb.
getter/setter pair
- thickness ↔ double?
-
The thickness of the scrollbar's thumb.
getter/setter pair
- thumbColor ↔ Color?
-
The Color of the scrollbar's thumb.
getter/setter pair
- thumbVisibility → bool?
-
Defines whether to show the scrollbar always or only when scrolling.
defaults to
truefinal - timeToFade ↔ Duration
-
The Duration of time until the fade animation begins.
Cannot be null, defaults to a Duration of 600 milliseconds.
getter/setter pair
- trackBorderColor ↔ Color?
-
The Color of the scrollbar's track border.
getter/setter pair
- trackColor ↔ Color?
-
The Color of the scrollbar's track.
getter/setter pair
- trackRadius ↔ Radius?
-
The Radius of the scrollbar's track.
getter/setter pair
- trackVisibility ↔ bool?
-
The Color of the scrollbar's track.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited