SearchFieldDimensions class
Constructors
Properties
- bottom → double?
-
Space Below the searchfield
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
height of the searchfield
final
- offset → Offset?
-
offset of the searchfield
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double?
-
Space Above the searchfield
final
- width → double?
-
width of the searchfield
final
Methods
-
copyWith(
{double? height, double? width, Offset? offset, double? top, double? bottom}) → SearchFieldDimensions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited