SearchFieldListItem<T> class
Constructors
-
SearchFieldListItem(String searchKey, {Widget? child, T? item, Key? key, String? value = ''})
-
The widget to be shown in the suggestion list.
if not specified, Text widget with default styling will be used.
searchKey is used to show the text in the suggestion list.
value is used to set the value in the searchField when the suggestion is selected
if not specified, the searchKey will be used.
item (optional) is used to pass the custom object to the widget
to show a custom widget, use child instead
see example in example/lib/country_search.dart
Properties
-
child
→ Widget?
-
The widget to be shown in the searchField suggestion list
if not specified, Text widget with default styling will be used
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
item
→ T?
-
Custom Object to be associated with each ListItem
For Suggestions with Custom Objects, pass item parameter to SearchFieldListItem
see example in example/lib/country_search.dart
final
-
key
↔ Key?
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchKey
→ String
-
the text based on which the search happens
final
-
value
→ String?
-
The value to set in the searchField when the suggestion is selected
if not specified, the searchKey will be used
final